@@ -32,11 +32,7 @@ Q_SIGNALS:
     void outputChanged();
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long int *result) override;
-#else
     bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
-#endif
 
 private:
     int m_randrBase;
